@@ -1,16 +1,13 @@
 ## File Name: Rfunction_include_argument_values.R
-## File Version: 0.17
+## File Version: 0.25
 
 Rfunction_include_argument_values <- function(string, maxlen=70)
 {
     ind1 <- string_find_first(string=string, symbol="(" )
-    # a1 <- strsplit( string, split="(", fixed=TRUE )[[1]]
-    a1 <- c( substring(string,1, ind1-1),
-                substring(string, ind1+1, nchar(string) ) )
+    a1 <- c( substring(string,1, ind1-1), substring(string, ind1+1, nchar(string) ) )
     s1 <- a1[2]
 
     ind1 <- string_find_last(string=s1, symbol=")" )
-    # s1 <- strsplit( s1, split=")", fixed=TRUE )[[1]][1]
     s1 <- substring(s1,1, ind1-1)
     s1 <- gsub("\n", "", s1 )
     s1 <- strsplit( s1, split=",", fixed=TRUE )[[1]]
@@ -31,5 +28,10 @@ Rfunction_include_argument_values <- function(string, maxlen=70)
         }
     }
     s2 <- paste0( a1[1], "( ", paste0( s2, collapse=", " ), " ) \n" )
+    #--- handle dots
+    s2 <- gsub("...=...", "...", s2, fixed=TRUE)
+    #--- delete blanks at begin of lines
+    s2 <- gsub("\n ", "\n", s2, fixed=TRUE)
+    #--- output
     return(s2)
 }
