@@ -1,10 +1,10 @@
 ## File Name: Rhat1.R
-## File Version: 1.04
+## File Version: 1.06
 
 
 ####################################
 # auxiliary functions for Rhat statistic
-        ############################################################################
+############################################################################
         # Code from rube package
         # Source: http://www.stat.cmu.edu/~hseltman/rube/rube0.2-16/R/Rhat.R
         # Inference from Iterative Simulation Using Multiple Sequences
@@ -13,12 +13,14 @@
         # Stable URL: http://www.jstor.org/stable/2246093
         ## Matches gelman.diag() from package "coda", but not WinBUGS() "summary" component.
         ## Better than gelman.diag() because multivariate stat is not bothered to be calculated
-Rhat1 <- function(mat) {
+
+Rhat1 <- function(mat)
+{
     m <- ncol(mat)
     n <- nrow(mat)
     b <- apply(mat,2,mean)
     B <- sum((b-mean(mat))^2)*n/(m-1)
-    w <- apply(mat,2,stats::var)
+    w <- apply(mat,2, stats::var)
     W <- mean(w)
     s2hat <- (n-1)/n*W + B/n
     Vhat <- s2hat + B/m/n
@@ -33,10 +35,11 @@ Rhat1 <- function(mat) {
 
 
 
-Rhat <- function(arr) {
-            dm <- dim(arr)
-            if (length(dm)==2) return(Rhat1(arr))
-            if (dm[2]==1) return(NULL)
-            if (dm[3]==1) return(Rhat1(arr[,,1]))
-            return(apply(arr,3,Rhat1))
-        }
+Rhat <- function(arr)
+{
+    dm <- dim(arr)
+    if (length(dm)==2) return(Rhat1(arr))
+    if (dm[2]==1) return(NULL)
+    if (dm[3]==1) return(Rhat1(arr[,,1]))
+    return(apply(arr,3,Rhat1))
+}
